@@ -122,7 +122,7 @@ class TestSearchTemplate(unittest.TestCase):
         bregex.purge()
         self.assertEqual(bregex._get_cache_size(), 0)
         self.assertEqual(bregex._get_cache_size(True), 0)
-        for x in range(1000):
+        for _ in range(1000):
             value = str(random.randint(1, 10000))
             p = bregex.compile(value)
             p.sub('', value)
@@ -147,9 +147,10 @@ class TestSearchTemplate(unittest.TestCase):
     def test_escape_char(self):
         """Test escape char."""
 
-        pattern = bregex.compile_search(
-            r'test\etest[\e]{2}'
-        )
+        with pytest.warns(DeprecationWarning):
+            pattern = bregex.compile_search(
+                r'test\etest[\e]{2}'
+            )
 
         self.assertEqual(
             pattern.pattern,
@@ -692,17 +693,21 @@ class TestReplaceTemplate(unittest.TestCase):
     def test_format_conversions(self):
         """Test string format conversion paths."""
 
-        self.assertTrue(bregex.subf('test', r'{0.index}', 'test').startswith('<built-in method'))
+        self.assertTrue(bregex.subf('test', r'{0.index}', 'test').startswith(('<built-in method', '<bound method')))
         self.assertEqual(bregex.subf('test', r'{0.__class__.__name__}', 'test'), 'str')
-        self.assertTrue(bregex.subf('test', r'{0.index!s}', 'test').startswith('<built-in method'))
+        self.assertTrue(bregex.subf('test', r'{0.index!s}', 'test').startswith(('<built-in method', '<bound method')))
         self.assertEqual(bregex.subf('test', r'{0.__class__.__name__!s}', 'test'), 'str')
-        self.assertTrue(bregex.subf('test', r'{0.index!a}', 'test').startswith('<built-in method'))
+        self.assertTrue(bregex.subf('test', r'{0.index!a}', 'test').startswith(('<built-in method', '<bound method')))
 
-        self.assertTrue(bregex.subf(b'test', br'{0.index}', b'test').startswith(b'<built-in method'))
+        self.assertTrue(bregex.subf(
+            b'test', br'{0.index}', b'test').startswith((b'<built-in method', b'<bound method'))
+        )
         self.assertEqual(bregex.subf(b'test', br'{0.__class__.__name__}', b'test'), b'bytes')
-        self.assertTrue(bregex.subf(b'test', br'{0.index!s}', b'test').startswith(b'<built-in method'))
+        self.assertTrue(
+            bregex.subf(b'test', br'{0.index!s}', b'test').startswith((b'<built-in method', b'<bound method'))
+        )
         self.assertEqual(bregex.subf(b'test', br'{0.__class__.__name__!s}', b'test'), b'bytes')
-        self.assertTrue(bregex.subf('test', r'{0.index!a}', 'test').startswith('<built-in method'))
+        self.assertTrue(bregex.subf('test', r'{0.index!a}', 'test').startswith(('<built-in method', '<bound method')))
 
     def test_incompatible_strings(self):
         """Test incompatible string types."""
@@ -1995,16 +2000,12 @@ class TestConvenienceFunctions(unittest.TestCase):
     def test_splititer(self):
         """Test that `split` works."""
 
-        array = []
-        for x in bregex.splititer(r'\W+', "This is a test for split!"):
-            array.append(x)
-
+        array = list(bregex.splititer(r'\W+', "This is a test for split!"))
         self.assertEqual(array, ["This", "is", "a", "test", "for", "split", ""])
 
         array = []
         p = bregex.compile(r'\W+')
-        for x in p.splititer("This is a test for split!"):
-            array.append(x)
+        array = list(p.splititer("This is a test for split!"))
 
         self.assertEqual(array, ["This", "is", "a", "test", "for", "split", ""])
 
@@ -2100,14 +2101,14 @@ class TestConvenienceFunctions(unittest.TestCase):
         """Test that `finditer` works."""
 
         count = 0
-        for m in bregex.finditer(r'\w+', 'This is a test for finditer!'):
+        for _ in bregex.finditer(r'\w+', 'This is a test for finditer!'):
             count += 1
 
         self.assertEqual(count, 6)
 
         count = 0
         p = bregex.compile(r'\w+')
-        for m in p.finditer('This is a test for finditer!'):
+        for _ in p.finditer('This is a test for finditer!'):
             count += 1
 
         self.assertEqual(count, 6)
