@@ -1,7 +1,6 @@
 """Generate a Unicode prop table for Python builds."""
 import sys
 import unicodedata
-import codecs
 import os
 import re
 
@@ -19,9 +18,9 @@ UNICODE_RANGE = (0x0000, 0x10FFFF)
 ASCII_RANGE = (0x00, 0xFF)
 ASCII_LIMIT = (0x00, 0x7F)
 
-ALL_CHARS = frozenset([x for x in range(UNICODE_RANGE[0], UNICODE_RANGE[1] + 1)])
-ASCII_UNUSED = frozenset([x for x in range(0x80, UNICODE_RANGE[1] + 1)])
-ALL_ASCII = frozenset([x for x in range(ASCII_RANGE[0], ASCII_RANGE[1] + 1)])
+ALL_CHARS = frozenset(list(range(UNICODE_RANGE[0], UNICODE_RANGE[1] + 1)))
+ASCII_UNUSED = frozenset(list(range(0x80, UNICODE_RANGE[1] + 1)))
+ALL_ASCII = frozenset(list(range(ASCII_RANGE[0], ASCII_RANGE[1] + 1)))
 HEADER = '''\
 """Unicode Properties from Unicode version {} (autogen)."""
 {}'''
@@ -58,7 +57,7 @@ def create_span(unirange, is_bytes=False):
             return []
         if unirange[1] > MAXVALIDASCII:
             unirange[1] = MAXVALIDASCII
-    return [x for x in range(unirange[0], unirange[1] + 1)]
+    return list(range(unirange[0], unirange[1] + 1))
 
 
 def not_explicitly_defined(table, name, is_bytes=False):
@@ -67,7 +66,7 @@ def not_explicitly_defined(table, name, is_bytes=False):
     name = name.lower()
     all_chars = ALL_CHARS
     s = set()
-    for k, v in table.items():
+    for v in table.values():
         s.update(v)
     if name in table:
         table[name] = list(set(table[name]) | (all_chars - s))
@@ -201,7 +200,7 @@ def discover_categories():
 
     # NF Quick Check categories
     file_name = os.path.join(HOME, 'unicodedata', UNIVERSION, 'DerivedNormalizationProps.txt')
-    with codecs.open(file_name, 'r', 'utf-8') as uf:
+    with open(file_name, 'r', encoding='utf-8') as uf:
         for line in uf:
             if not line.startswith('#'):
                 data = line.split('#')[0].split(';')
@@ -227,7 +226,7 @@ def discover_categories():
         binary_props.append(('emoji-data.txt', None))
 
     for filename, include in binary_props:
-        with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, filename), 'r', 'utf-8') as uf:
+        with open(os.path.join(HOME, 'unicodedata', UNIVERSION, filename), 'r', encoding='utf-8') as uf:
             for line in uf:
                 if not line.startswith('#'):
                     data = line.split('#')[0].split(';')
@@ -245,19 +244,19 @@ def discover_categories():
 def gen_blocks(output, ascii_props=False, append=False, prefix="", aliases=None):
     """Generate Unicode blocks."""
 
-    with codecs.open(output, 'a' if append else 'w', 'utf-8') as f:
+    with open(output, 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         f.write('%s_blocks: dict[str, str] = {' % prefix)
         no_block = []
         last = -1
-        found = set(['noblock'])
+        found = {'noblock'}
 
         max_limit = MAXVALIDASCII if ascii_props else MAXUNICODE
         max_range = MAXUNICODE
         formatter = uniformat
 
-        with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'Blocks.txt'), 'r', 'utf-8') as uf:
+        with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'Blocks.txt'), 'r', encoding='utf-8') as uf:
             for line in uf:
                 if not line.startswith('#'):
                     data = line.split(';')
@@ -321,7 +320,7 @@ def gen_ccc(output, ascii_props=False, append=False, prefix="", aliases=None):
         for v in aliases.get('canonicalcombiningclass', {}).values():
             obj[v] = []
 
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'DerivedCombiningClass.txt'), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'DerivedCombiningClass.txt'), 'r', encoding='utf-8') as uf:
         for line in uf:
             if not line.startswith('#'):
                 data = line.split('#')[0].split(';')
@@ -350,7 +349,7 @@ def gen_ccc(output, ascii_props=False, append=False, prefix="", aliases=None):
     # Convert characters values to ranges
     char2range(obj, is_bytes=ascii_props)
 
-    with codecs.open(output, 'a' if append else 'w', 'utf-8') as f:
+    with open(output, 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         # Write out the Unicode properties
@@ -382,13 +381,13 @@ def gen_scripts(
             obj2[v] = []
 
     alias = {}
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'PropertyValueAliases.txt'), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'PropertyValueAliases.txt'), 'r', encoding='utf-8') as uf:
         for line in uf:
             if line.startswith('sc ;'):
                 values = line.split(';')
                 alias[format_name(values[1].strip())] = format_name(values[2].strip())
 
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, file_name_ext), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, file_name_ext), 'r', encoding='utf-8') as uf:
         for line in uf:
             if not line.startswith('#'):
                 data = line.split('#')[0].split(';')
@@ -404,7 +403,7 @@ def gen_scripts(
 
                     obj2[ext].extend(span)
 
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, file_name), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, file_name), 'r', encoding='utf-8') as uf:
         for line in uf:
             if not line.startswith('#'):
                 data = line.split('#')[0].split(';')
@@ -439,7 +438,7 @@ def gen_scripts(
     char2range(obj, is_bytes=ascii_props)
     char2range(obj2, is_bytes=ascii_props)
 
-    with codecs.open(output, 'a' if append else 'w', 'utf-8') as f:
+    with open(output, 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         # Write out the Unicode properties
@@ -454,7 +453,7 @@ def gen_scripts(
                 f.write(',\n')
             i += 1
 
-    with codecs.open(output_ext, 'a' if append else 'w', 'utf-8') as f:
+    with open(output_ext, 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         # Write out the Unicode properties
@@ -482,7 +481,7 @@ def gen_enum(
         for v in aliases.get(format_name(obj_name), {}).values():
             obj[v] = []
 
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, file_name), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, file_name), 'r', encoding='utf-8') as uf:
         for line in uf:
             if not line.startswith('#'):
                 data = line.split('#')[0].split(';')
@@ -508,7 +507,7 @@ def gen_enum(
     # Convert characters values to ranges
     char2range(obj, is_bytes=ascii_props)
 
-    with codecs.open(output, 'a' if append else 'w', 'utf-8') as f:
+    with open(output, 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         # Write out the Unicode properties
@@ -535,7 +534,7 @@ def gen_age(output, ascii_props=False, append=False, prefix="", aliases=None):
             obj[v] = []
 
     all_chars = (ALL_CHARS - ASCII_UNUSED) if ascii_props else ALL_CHARS
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'DerivedAge.txt'), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'DerivedAge.txt'), 'r', encoding='utf-8') as uf:
         for line in uf:
             if not line.startswith('#'):
                 data = line.split('#')[0].split(';')
@@ -564,7 +563,7 @@ def gen_age(output, ascii_props=False, append=False, prefix="", aliases=None):
     # Convert characters values to ranges
     char2range(obj, is_bytes=ascii_props)
 
-    with codecs.open(output, 'a' if append else 'w', 'utf-8') as f:
+    with open(output, 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         # Write out the Unicode properties
@@ -586,7 +585,7 @@ def gen_nf_quick_check(output, ascii_props=False, append=False, prefix="", alias
     nf = {}
     all_chars = (ALL_CHARS - ASCII_UNUSED) if ascii_props else ALL_CHARS
     file_name = os.path.join(HOME, 'unicodedata', UNIVERSION, 'DerivedNormalizationProps.txt')
-    with codecs.open(file_name, 'r', 'utf-8') as uf:
+    with open(file_name, 'r', encoding='utf-8') as uf:
         for line in uf:
             if not line.startswith('#'):
                 data = line.split('#')[0].split(';')
@@ -612,7 +611,7 @@ def gen_nf_quick_check(output, ascii_props=False, append=False, prefix="", alias
 
                 nf[name][subvalue].extend(span)
 
-    for k1, v1 in nf.items():
+    for v1 in nf.values():
         temp = set()
         for k2 in list(v1.keys()):
             temp |= set(v1[k2])
@@ -626,7 +625,7 @@ def gen_nf_quick_check(output, ascii_props=False, append=False, prefix="", alias
     # Convert characters values to ranges
     char2range(nf, is_bytes=ascii_props)
 
-    with codecs.open(output, 'a' if append else 'w', 'utf-8') as f:
+    with open(output, 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         for key, value in sorted(nf.items()):
@@ -670,7 +669,7 @@ def gen_binary(table, output, ascii_props=False, append=False, prefix="", aliase
     binary['vertspace'] = [x for x in binary['vertspace'] if x <= max_range]
 
     for filename, include in binary_props:
-        with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, filename), 'r', 'utf-8') as uf:
+        with open(os.path.join(HOME, 'unicodedata', UNIVERSION, filename), 'r', encoding='utf-8') as uf:
             for line in uf:
                 if not line.startswith('#'):
                     data = line.split('#')[0].split(';')
@@ -687,7 +686,7 @@ def gen_binary(table, output, ascii_props=False, append=False, prefix="", aliase
                         continue
                     binary[name].extend(span)
 
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'CompositionExclusions.txt'), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'CompositionExclusions.txt'), 'r', encoding='utf-8') as uf:
         name = 'compositionexclusion'
         for line in uf:
             if not line.startswith('#'):
@@ -703,7 +702,7 @@ def gen_binary(table, output, ascii_props=False, append=False, prefix="", aliase
                 binary[name].extend(span)
 
     file_name = os.path.join(HOME, 'unicodedata', UNIVERSION, 'DerivedNormalizationProps.txt')
-    with codecs.open(file_name, 'r', 'utf-8') as uf:
+    with open(file_name, 'r', encoding='utf-8') as uf:
         name = "fullcompositionexclusion"
         for line in uf:
             if not line.startswith('#'):
@@ -720,7 +719,7 @@ def gen_binary(table, output, ascii_props=False, append=False, prefix="", aliase
                     binary[name] = []
                 binary[name].extend(span)
 
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'UnicodeData.txt'), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'UnicodeData.txt'), 'r', encoding='utf-8') as uf:
         name = 'bidimirrored'
         for line in uf:
             data = line.strip().split(';')
@@ -744,9 +743,9 @@ def gen_binary(table, output, ascii_props=False, append=False, prefix="", aliase
     # One off Unicode property found under https://unicode.org/reports/tr18/#Compatibility_Properties
     # `Word: [\p{alnum}\p{M}\p{Pc}\p{JoinControl}]`
     s = set(binary["alnum"])
-    s |= set(table['m']['c'])
-    s |= set(table['m']['e'])
-    s |= set(table['m']['n'])
+    for k, v in table['m'].items():
+        if not k.startswith('^'):
+            s |= set(v)
     s |= set(table["p"]["c"])
     s |= set(binary["joincontrol"])
     binary["word"] = list(s)
@@ -759,7 +758,7 @@ def gen_binary(table, output, ascii_props=False, append=False, prefix="", aliase
     # Convert characters values to ranges
     char2range(binary, is_bytes=ascii_props)
 
-    with codecs.open(output, 'a' if append else 'w', 'utf-8') as f:
+    with open(output, 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         # Write out the Unicode properties
@@ -786,7 +785,7 @@ def gen_bidi(output, ascii_props=False, append=False, prefix="", aliases=None):
             bidi_class[v] = []
 
     max_range = MAXVALIDASCII if ascii_props else MAXUNICODE
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'UnicodeData.txt'), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'UnicodeData.txt'), 'r', encoding='utf-8') as uf:
         for line in uf:
             data = line.strip().split(';')
             if data:
@@ -810,7 +809,7 @@ def gen_bidi(output, ascii_props=False, append=False, prefix="", aliases=None):
     # Convert characters values to ranges
     char2range(bidi_class, is_bytes=ascii_props)
 
-    with codecs.open(output, 'a' if append else 'w', 'utf-8') as f:
+    with open(output, 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         f.write('%s_bidi_classes: dict[str, str] = {\n' % prefix)
@@ -838,7 +837,7 @@ def gen_uposix(table, posix_table, ascii_props):
     posix_table["posixpunct"] = list(s)
 
     # `Digit: [0-9]`
-    s = set([x for x in range(0x30, 0x39 + 1)])
+    s = set(range(0x30, 0x39 + 1))
     posix_table["posixdigit"] = list(s)
 
     # `XDigit: [\p{Nd}\p{HexDigit}]`
@@ -846,9 +845,9 @@ def gen_uposix(table, posix_table, ascii_props):
     posix_table["xdigit"] = list(s)
 
     # `XDigit: [A-Fa-f0-9]`
-    s = set([x for x in range(0x30, 0x39 + 1)])
-    s |= set([x for x in range(0x41, 0x46 + 1)])
-    s |= set([x for x in range(0x61, 0x66 + 1)])
+    s = set(range(0x30, 0x39 + 1))
+    s |= set(range(0x41, 0x46 + 1))
+    s |= set(range(0x61, 0x66 + 1))
     posix_table["posixxdigit"] = list(s)
 
     # `Alnum: [\p{PosixAlpha}\p{PosixDigit}]`
@@ -883,7 +882,7 @@ def gen_uposix(table, posix_table, ascii_props):
     posix_table["posixprint"] = list(s)
 
     # `ASCII: [\x00-\x7F]`
-    s = set([x for x in range(0, 0x7F + 1)])
+    s = set(range(0, 0x7F + 1))
     posix_table["posixascii"] = list(s)
 
 
@@ -913,7 +912,7 @@ def gen_alias(nonbinary, binary, output):
         'catalog', 'enumerated', 'numeric', 'miscellaneous'
     )
 
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'PropertyAliases.txt'), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'PropertyAliases.txt'), 'r', encoding='utf-8') as uf:
         div = False
         capture = False
         name = None
@@ -952,7 +951,7 @@ def gen_alias(nonbinary, binary, output):
                     for d in data[1:]:
                         alias[name][d] = data[0]
 
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'PropertyValueAliases.txt'), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'PropertyValueAliases.txt'), 'r', encoding='utf-8') as uf:
         for line in uf:
             m = alias_re.match(line)
             if m:
@@ -992,7 +991,7 @@ def gen_alias(nonbinary, binary, output):
     alias['binary']['h'] = 'horizspace'
     alias['binary']['v'] = 'vertspace'
 
-    with codecs.open(output, 'w', 'utf-8') as f:
+    with open(output, 'w', encoding='utf-8') as f:
         f.write(HEADER.format(UNIVERSION, TYPING))
         f.write('%s_alias: dict[str, dict[str, str]] = {\n' % prefix)
         count = len(alias) - 1
@@ -1037,7 +1036,7 @@ def gen_properties(output, files, aliases, ascii_props=False, append=False):
     # before sending it through.
     table = {'l': {'c': []}}
     itable = {'l': {}}
-    with codecs.open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'UnicodeData.txt'), 'r', 'utf-8') as uf:
+    with open(os.path.join(HOME, 'unicodedata', UNIVERSION, 'UnicodeData.txt'), 'r', encoding='utf-8') as uf:
         for line in uf:
             data = line.strip().split(';')
             if data:
@@ -1056,15 +1055,15 @@ def gen_properties(output, files, aliases, ascii_props=False, append=False):
                     table['l']['c'].append(i)
 
     s = set()
-    for k, v in table.items():
-        for k2, v2 in v.items():
+    for v in table.values():
+        for v2 in v.values():
             s.update(v2)
     table['c']['n'] = list(all_chars - s)
 
     # Create inverse of each category
     for k1, v1 in table.items():
         inverse_category = set()
-        for k2, v2 in v1.items():
+        for v2 in v1.values():
             s = set(v2)
             inverse_category |= s
         itable[k1]['^'] = list(all_chars - inverse_category)
@@ -1194,7 +1193,7 @@ def gen_properties(output, files, aliases, ascii_props=False, append=False):
     for k1, v1 in itable.items():
         table[k1]['^'] = v1['^']
 
-    with codecs.open(files['gc'], 'a' if append else 'w', 'utf-8') as f:
+    with open(files['gc'], 'a' if append else 'w', encoding='utf-8') as f:
         if not append:
             f.write(HEADER.format(UNIVERSION, TYPING))
         # Write out the Unicode properties
@@ -1219,7 +1218,7 @@ def gen_properties(output, files, aliases, ascii_props=False, append=False):
             i += 1
 
     if not append:
-        with codecs.open(os.path.join(output, '__init__.py'), 'w') as f:
+        with open(os.path.join(output, '__init__.py'), 'w') as f:
             f.write(HEADER.format(UNIVERSION, ''))
             for x in sorted(files):
                 f.write('from .%s import *  # noqa\n' % os.path.basename(files[x])[:-3])
